Release Notes
=============

v0.1.8
------
* Fixed migrations to include south_migrations

v0.1.7
------

* Fixed upload to pypi

v0.1.6
------

* Updated for Django 1.7 compatibility

v0.1.4
------

* This release of django-db-mutex includes docs buildout
* python 3.3, 3.4 compatibility
